@@ -378,6 +378,7 @@ module RHC
         @debug ||= false
 
         @auth = options.delete(:auth)
+        @api_always_auth = options.delete(:api_always_auth)
 
         self.headers.merge!(options.delete(:headers)) if options[:headers]
         self.options.merge!(options)
@@ -389,6 +390,10 @@ module RHC
         @end_point
       end
 
+      def api_always_auth
+        @api_always_auth
+      end
+
       def api
         @api ||= RHC::Rest::Api.new(self, @preferred_api_versions).tap do |api|
           self.current_api_version = api.api_version_negotiated
@@ -436,7 +441,7 @@ module RHC
               handle_error!(e.res, args[1], client)
             end
             raise ConnectionException.new(
-              "An unexpected error occured when connecting to the server: #{e.message}")
+              "An unexpected error occurred when connecting to the server: #{e.message}")
           rescue HTTPClient::TimeoutError => e
             raise TimeoutException.new(
               "Connection to server timed out. "\
@@ -493,7 +498,7 @@ module RHC
             raise
           rescue => e
             debug_error(e)
-            raise ConnectionException, "An unexpected error occured: #{e.message}", e.backtrace
+            raise ConnectionException, "An unexpected error occurred: #{e.message}", e.backtrace
           end
         end
       end
